@@ -479,6 +479,32 @@ int CalcEngine::reduce_Stack_(bool toParentheses /*= true*/)
                 token_stack_.last().updateToken(result);
                 continue;
             }
+            if (token_stack_.at(token_stack_.size() - 1).isKNumber() && token_stack_.at(token_stack_.size() - 2).isBinaryFunction()
+                && token_stack_.at(token_stack_.size() - 3).isKNumber() && token_stack_.at(token_stack_.size() - 4).isBinaryFunction()) {
+
+                if (token_stack_.at(token_stack_.size() - 2).getTokenCode() == KCalcToken::TokenCode::MINUS || token_stack_.at(token_stack_.size() - 2).getTokenCode() == KCalcToken::TokenCode::PLUS) {
+                    if (token_stack_.at(token_stack_.size() - 4).getTokenCode() == KCalcToken::TokenCode::MINUS) {
+
+                        tokenSecondArg = &token_stack_.at(token_stack_.size() - 1);
+                        tokenFunction = &token_stack_.at(token_stack_.size() - 2);
+                        tokenFirstArg = &token_stack_.at(token_stack_.size() - 3);
+                        KNumber result;
+                        if (tokenFunction->isSecondArgInverted()) {
+                            result = tokenFunction->evaluate(tokenFirstArg->getKNumber(), tokenSecondArg->getKNumber());
+                        } else {
+                            result = tokenFunction->evaluate(-tokenFirstArg->getKNumber(), tokenSecondArg->getKNumber());
+
+                        }
+                        token_stack_.pop_back();
+                        token_stack_.pop_back();
+                        token_stack_.pop_back();
+                        token_stack_.last().updateToken(KCalcToken::TokenCode::PLUS);
+                        token_stack_.push_back(KCalcToken(result));
+                        continue;
+                    }
+                }
+
+            }
         }
 
         if (token_stack_.size() > 2) {
@@ -514,6 +540,7 @@ int CalcEngine::reduce_Stack_(bool toParentheses /*= true*/)
             KNumber result = -token_stack_.last().getKNumber();
             token_stack_.pop_back();
             token_stack_.last().updateToken(result);
+            continue;
         }
 
         qDebug() << "Error at stack size = " << token_stack_.size();
